@@ -5,42 +5,31 @@ from ucloud.services.uhost.schemas import apis
 
 
 class UHostClient(Client):
-    def __init__(self, config: dict, transport=None, middleware=None):
-        super(UHostClient, self).__init__(config, transport, middleware)
+    def __init__(self, config: dict, transport=None, middleware=None, logger=None):
+        super(UHostClient, self).__init__(config, transport, middleware, logger)
 
-    def stop_uhost_instance(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ StopUHostInstance - 指停止处于运行状态的UHost实例，需指定数据中心及UhostID。
+    def resize_uhost_instance(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ ResizeUHostInstance - 修改指定UHost实例的资源配置，如CPU核心数，内存容量大小，网络增强等。可选配置范围请参考[[api:uhost-api:uhost_type|云主机机型说明]]。
 
         :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
         :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
         :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
+        :param BootDiskSpace: (Optional) 【待废弃】系统盘大小，单位：GB，范围[20,100]，步长：10，系统盘不支持缩容，因此不允许输入比当前实例系统盘小的值
+        :param CPU: (Optional) 虚拟CPU核数。可选参数：1-32（可选范围与UHostType相关）。默认值为当前实例的CPU核数
+        :param DiskSpace: (Optional) 【待废弃】数据盘大小，单位：GB，范围[10,1000]； SSD机型，单位：GB，范围[100,500]；步长：10，默认值为当前实例的数据盘大小，数据盘不支持缩容，因此不允许输入比当前实例数据盘大小的值
+        :param Memory: (Optional) 内存大小。单位：MB。范围 ：[1024, 262144]，取值为1024的倍数（可选范围与UHostType相关）。默认值为当前实例的内存大小。
+        :param NetCapValue: (Optional) 网卡升降级（1，表示升级，2表示降级，0表示不变）
         :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
         """
         # build request
         d = {"ProjectId": self.config.project_id, "Region": self.config.region}
         req and d.update(req)
-        d = apis.StopUHostInstanceRequestSchema().dumps(d)
+        d = apis.ResizeUHostInstanceRequestSchema().dumps(d)
 
-        resp = self.invoke("StopUHostInstance", d, **kwargs)
-        return apis.StopUHostInstanceResponseSchema().loads(resp)
-
-    def upgrade_to_ark_uhost_instance(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ UpgradeToArkUHostInstance - 普通升级为方舟机型
-
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param UHostIds: (Required) UHost主机的资源ID，例如UHostIds.0代表希望升级的主机1，UHostIds.1代表主机2。
-        :param Zone: (Required) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        :param CouponId: (Optional) 代金券ID 请参考DescribeCoupon接口
-        """
-        # build request
-        d = {"Region": self.config.region}
-        req and d.update(req)
-        d = apis.UpgradeToArkUHostInstanceRequestSchema().dumps(d)
-
-        resp = self.invoke("UpgradeToArkUHostInstance", d, **kwargs)
-        return apis.UpgradeToArkUHostInstanceResponseSchema().loads(resp)
+        resp = self.invoke("ResizeUHostInstance", d, **kwargs)
+        return apis.ResizeUHostInstanceResponseSchema().loads(resp)
 
     def copy_custom_image(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
         """ CopyCustomImage - 复制自制镜像
@@ -119,6 +108,25 @@ class UHostClient(Client):
         resp = self.invoke("GetUHostInstancePrice", d, **kwargs)
         return apis.GetUHostInstancePriceResponseSchema().loads(resp)
 
+    def modify_uhost_instance_remark(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ ModifyUHostInstanceRemark - 修改指定UHost实例备注信息。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
+        :param Remark: (Optional) 备注
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.ModifyUHostInstanceRemarkRequestSchema().dumps(d)
+
+        resp = self.invoke("ModifyUHostInstanceRemark", d, **kwargs)
+        return apis.ModifyUHostInstanceRemarkResponseSchema().loads(resp)
+
     def reboot_uhost_instance(
         self, req: typing.Optional[dict] = None, **kwargs
     ) -> dict:
@@ -138,105 +146,6 @@ class UHostClient(Client):
         resp = self.invoke("RebootUHostInstance", d, **kwargs)
         return apis.RebootUHostInstanceResponseSchema().loads(resp)
 
-    def resize_attached_disk(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ ResizeAttachedDisk - 修改挂载的磁盘大小，包含系统盘和数据盘
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param DiskId: (Required) 磁盘ID。参见 [DescribeUHostInstance](describe_uhost_instance.html)返回值中的DiskSet。
-        :param DiskSpace: (Required) 磁盘大小，单位GB，步长为10。取值范围需大于当前磁盘大小，最大值请参考[[api:uhost-api:disk_type|磁盘类型]]。
-        :param UHostId: (Required) UHost实例ID。 参见 [DescribeUHostInstance](describe_uhost_instance.html)。
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.ResizeAttachedDiskRequestSchema().dumps(d)
-
-        resp = self.invoke("ResizeAttachedDisk", d, **kwargs)
-        return apis.ResizeAttachedDiskResponseSchema().loads(resp)
-
-    def resize_uhost_instance(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ ResizeUHostInstance - 修改指定UHost实例的资源配置，如CPU核心数，内存容量大小，网络增强等。可选配置范围请参考[[api:uhost-api:uhost_type|云主机机型说明]]。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
-        :param BootDiskSpace: (Optional) 【待废弃】系统盘大小，单位：GB，范围[20,100]，步长：10，系统盘不支持缩容，因此不允许输入比当前实例系统盘小的值
-        :param CPU: (Optional) 虚拟CPU核数。可选参数：1-32（可选范围与UHostType相关）。默认值为当前实例的CPU核数
-        :param DiskSpace: (Optional) 【待废弃】数据盘大小，单位：GB，范围[10,1000]； SSD机型，单位：GB，范围[100,500]；步长：10，默认值为当前实例的数据盘大小，数据盘不支持缩容，因此不允许输入比当前实例数据盘大小的值
-        :param Memory: (Optional) 内存大小。单位：MB。范围 ：[1024, 262144]，取值为1024的倍数（可选范围与UHostType相关）。默认值为当前实例的内存大小。
-        :param NetCapValue: (Optional) 网卡升降级（1，表示升级，2表示降级，0表示不变）
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.ResizeUHostInstanceRequestSchema().dumps(d)
-
-        resp = self.invoke("ResizeUHostInstance", d, **kwargs)
-        return apis.ResizeUHostInstanceResponseSchema().loads(resp)
-
-    def describe_uhost_instance(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ DescribeUHostInstance - 获取主机或主机列表信息，并可根据数据中心，主机ID等参数进行过滤。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param IsolationGroup: (Optional) 硬件隔离组id。通过硬件隔离组筛选主机。
-        :param LifeCycle: (Optional) 1：普通云主机；2：抢占型云主机；如不传此参数，默认全部获取
-        :param Limit: (Optional) 返回数据长度，默认为20，最大100
-        :param Offset: (Optional) 列表起始位置偏移量，默认为0
-        :param SubnetId: (Optional) 子网id。通过子网筛选主机。北京一地域无效。
-        :param Tag: (Optional) 要查询的业务组名称
-        :param UHostIds: (Optional) 【数组】UHost主机的资源ID，例如UHostIds.0代表希望获取信息 的主机1，UHostIds.1代表主机2。 如果不传入，则返回当前Region 所有符合条件的UHost实例。
-        :param VPCId: (Optional) vpc id。通过VPC筛选主机。北京一地域无效。
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.DescribeUHostInstanceRequestSchema().dumps(d)
-
-        resp = self.invoke("DescribeUHostInstance", d, **kwargs)
-        return apis.DescribeUHostInstanceResponseSchema().loads(resp)
-
-    def describe_uhost_tags(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ DescribeUHostTags - 获取指定数据中心的业务组列表。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.DescribeUHostTagsRequestSchema().dumps(d)
-
-        resp = self.invoke("DescribeUHostTags", d, **kwargs)
-        return apis.DescribeUHostTagsResponseSchema().loads(resp)
-
-    def poweroff_uhost_instance(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ PoweroffUHostInstance - 直接关闭UHost实例电源，无需等待实例正常关闭。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](./describe_uhost_instance.html)
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.PoweroffUHostInstanceRequestSchema().dumps(d)
-
-        resp = self.invoke("PoweroffUHostInstance", d, **kwargs)
-        return apis.PoweroffUHostInstanceResponseSchema().loads(resp)
-
     def reinstall_uhost_instance(
         self, req: typing.Optional[dict] = None, **kwargs
     ) -> dict:
@@ -261,6 +170,124 @@ class UHostClient(Client):
         resp = self.invoke("ReinstallUHostInstance", d, **kwargs)
         return apis.ReinstallUHostInstanceResponseSchema().loads(resp)
 
+    def reset_uhost_instance_password(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ ResetUHostInstancePassword - 重置UHost实例的管理员密码。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param Password: (Required) UHost新密码（密码格式使用BASE64编码）
+        :param UHostId: (Required) UHost实例ID
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.ResetUHostInstancePasswordRequestSchema().dumps(d)
+
+        resp = self.invoke("ResetUHostInstancePassword", d, **kwargs)
+        return apis.ResetUHostInstancePasswordResponseSchema().loads(resp)
+
+    def create_custom_image(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ CreateCustomImage - 从指定UHost实例，生成自定义镜像。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param ImageName: (Required) 镜像名称
+        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
+        :param ImageDescription: (Optional) 镜像描述
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.CreateCustomImageRequestSchema().dumps(d)
+
+        # build options
+        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent
+
+        resp = self.invoke("CreateCustomImage", d, **kwargs)
+        return apis.CreateCustomImageResponseSchema().loads(resp)
+
+    def import_custom_image(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ ImportCustomImage - 把UFile的镜像文件导入到UHost，生成自定义镜像
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param Auth: (Required) 是否授权。必须填true
+        :param Format: (Required) 镜像格式，可选RAW、VHD、VMDK、qcow2
+        :param ImageName: (Required) 镜像名称
+        :param OsName: (Required) 操作系统详细版本，请参考控制台的镜像版本；OsType为Other时，输入参数为Other
+        :param OsType: (Required) 操作系统平台，比如CentOS、Ubuntu、Windows、RedHat等，请参考控制台的镜像版本；若导入控制台上没有的操作系统，参数为Other
+        :param UFileUrl: (Required) UFile私有空间地址
+        :param ImageDescription: (Optional) 镜像描述
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.ImportCustomImageRequestSchema().dumps(d)
+
+        # build options
+        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent
+
+        resp = self.invoke("ImportCustomImage", d, **kwargs)
+        return apis.ImportCustomImageResponseSchema().loads(resp)
+
+    def modify_uhost_instance_tag(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ ModifyUHostInstanceTag - 修改指定UHost实例业务组标识。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
+        :param Tag: (Optional) 业务组名称
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.ModifyUHostInstanceTagRequestSchema().dumps(d)
+
+        resp = self.invoke("ModifyUHostInstanceTag", d, **kwargs)
+        return apis.ModifyUHostInstanceTagResponseSchema().loads(resp)
+
+    def resize_attached_disk(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ ResizeAttachedDisk - 修改挂载的磁盘大小，包含系统盘和数据盘
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param DiskId: (Required) 磁盘ID。参见 [DescribeUHostInstance](describe_uhost_instance.html)返回值中的DiskSet。
+        :param DiskSpace: (Required) 磁盘大小，单位GB，步长为10。取值范围需大于当前磁盘大小，最大值请参考[[api:uhost-api:disk_type|磁盘类型]]。
+        :param UHostId: (Required) UHost实例ID。 参见 [DescribeUHostInstance](describe_uhost_instance.html)。
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.ResizeAttachedDiskRequestSchema().dumps(d)
+
+        resp = self.invoke("ResizeAttachedDisk", d, **kwargs)
+        return apis.ResizeAttachedDiskResponseSchema().loads(resp)
+
+    def start_uhost_instance(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ StartUHostInstance - 启动处于关闭状态的UHost实例，需要指定数据中心及UHostID两个参数的值。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
+        :param DiskPassword: (Optional) 加密盘密码
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.StartUHostInstanceRequestSchema().dumps(d)
+
+        resp = self.invoke("StartUHostInstance", d, **kwargs)
+        return apis.StartUHostInstanceResponseSchema().loads(resp)
+
     def terminate_uhost_instance(
         self, req: typing.Optional[dict] = None, **kwargs
     ) -> dict:
@@ -341,103 +368,30 @@ class UHostClient(Client):
         resp = self.invoke("CreateUHostInstance", d, **kwargs)
         return apis.CreateUHostInstanceResponseSchema().loads(resp)
 
-    def import_custom_image(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ ImportCustomImage - 把UFile的镜像文件导入到UHost，生成自定义镜像
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param Auth: (Required) 是否授权。必须填true
-        :param Format: (Required) 镜像格式，可选RAW、VHD、VMDK、qcow2
-        :param ImageName: (Required) 镜像名称
-        :param OsName: (Required) 操作系统详细版本，请参考控制台的镜像版本；OsType为Other时，输入参数为Other
-        :param OsType: (Required) 操作系统平台，比如CentOS、Ubuntu、Windows、RedHat等，请参考控制台的镜像版本；若导入控制台上没有的操作系统，参数为Other
-        :param UFileUrl: (Required) UFile私有空间地址
-        :param ImageDescription: (Optional) 镜像描述
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.ImportCustomImageRequestSchema().dumps(d)
-
-        # build options
-        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent
-
-        resp = self.invoke("ImportCustomImage", d, **kwargs)
-        return apis.ImportCustomImageResponseSchema().loads(resp)
-
-    def start_uhost_instance(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ StartUHostInstance - 启动处于关闭状态的UHost实例，需要指定数据中心及UHostID两个参数的值。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
-        :param DiskPassword: (Optional) 加密盘密码
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.StartUHostInstanceRequestSchema().dumps(d)
-
-        resp = self.invoke("StartUHostInstance", d, **kwargs)
-        return apis.StartUHostInstanceResponseSchema().loads(resp)
-
-    def reset_uhost_instance_password(
+    def describe_uhost_instance(
         self, req: typing.Optional[dict] = None, **kwargs
     ) -> dict:
-        """ ResetUHostInstancePassword - 重置UHost实例的管理员密码。
+        """ DescribeUHostInstance - 获取主机或主机列表信息，并可根据数据中心，主机ID等参数进行过滤。
 
         :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
         :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param Password: (Required) UHost新密码（密码格式使用BASE64编码）
-        :param UHostId: (Required) UHost实例ID
+        :param IsolationGroup: (Optional) 硬件隔离组id。通过硬件隔离组筛选主机。
+        :param LifeCycle: (Optional) 1：普通云主机；2：抢占型云主机；如不传此参数，默认全部获取
+        :param Limit: (Optional) 返回数据长度，默认为20，最大100
+        :param Offset: (Optional) 列表起始位置偏移量，默认为0
+        :param SubnetId: (Optional) 子网id。通过子网筛选主机。北京一地域无效。
+        :param Tag: (Optional) 要查询的业务组名称
+        :param UHostIds: (Optional) 【数组】UHost主机的资源ID，例如UHostIds.0代表希望获取信息 的主机1，UHostIds.1代表主机2。 如果不传入，则返回当前Region 所有符合条件的UHost实例。
+        :param VPCId: (Optional) vpc id。通过VPC筛选主机。北京一地域无效。
         :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
         """
         # build request
         d = {"ProjectId": self.config.project_id, "Region": self.config.region}
         req and d.update(req)
-        d = apis.ResetUHostInstancePasswordRequestSchema().dumps(d)
+        d = apis.DescribeUHostInstanceRequestSchema().dumps(d)
 
-        resp = self.invoke("ResetUHostInstancePassword", d, **kwargs)
-        return apis.ResetUHostInstancePasswordResponseSchema().loads(resp)
-
-    def terminate_custom_image(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ TerminateCustomImage - 删除用户自定义镜像
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param ImageId: (Required) 自制镜像ID 参见 [DescribeImage](describe_image.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.TerminateCustomImageRequestSchema().dumps(d)
-
-        resp = self.invoke("TerminateCustomImage", d, **kwargs)
-        return apis.TerminateCustomImageResponseSchema().loads(resp)
-
-    def create_custom_image(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
-        """ CreateCustomImage - 从指定UHost实例，生成自定义镜像。
-
-        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
-        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param ImageName: (Required) 镜像名称
-        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
-        :param ImageDescription: (Optional) 镜像描述
-        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
-        """
-        # build request
-        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
-        req and d.update(req)
-        d = apis.CreateCustomImageRequestSchema().dumps(d)
-
-        # build options
-        kwargs["max_retries"] = 0  # ignore retry when api is not idempotent
-
-        resp = self.invoke("CreateCustomImage", d, **kwargs)
-        return apis.CreateCustomImageResponseSchema().loads(resp)
+        resp = self.invoke("DescribeUHostInstance", d, **kwargs)
+        return apis.DescribeUHostInstanceResponseSchema().loads(resp)
 
     def get_uhost_instance_vnc_info(
         self, req: typing.Optional[dict] = None, **kwargs
@@ -501,40 +455,86 @@ class UHostClient(Client):
         resp = self.invoke("ModifyUHostInstanceName", d, **kwargs)
         return apis.ModifyUHostInstanceNameResponseSchema().loads(resp)
 
-    def modify_uhost_instance_remark(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ ModifyUHostInstanceRemark - 修改指定UHost实例备注信息。
+    def stop_uhost_instance(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ StopUHostInstance - 指停止处于运行状态的UHost实例，需指定数据中心及UhostID。
 
         :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
         :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
         :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
-        :param Remark: (Optional) 备注
         :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
         """
         # build request
         d = {"ProjectId": self.config.project_id, "Region": self.config.region}
         req and d.update(req)
-        d = apis.ModifyUHostInstanceRemarkRequestSchema().dumps(d)
+        d = apis.StopUHostInstanceRequestSchema().dumps(d)
 
-        resp = self.invoke("ModifyUHostInstanceRemark", d, **kwargs)
-        return apis.ModifyUHostInstanceRemarkResponseSchema().loads(resp)
+        resp = self.invoke("StopUHostInstance", d, **kwargs)
+        return apis.StopUHostInstanceResponseSchema().loads(resp)
 
-    def modify_uhost_instance_tag(
-        self, req: typing.Optional[dict] = None, **kwargs
-    ) -> dict:
-        """ ModifyUHostInstanceTag - 修改指定UHost实例业务组标识。
+    def describe_uhost_tags(self, req: typing.Optional[dict] = None, **kwargs) -> dict:
+        """ DescribeUHostTags - 获取指定数据中心的业务组列表。
 
         :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
         :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
-        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](describe_uhost_instance.html)
-        :param Tag: (Optional) 业务组名称
         :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
         """
         # build request
         d = {"ProjectId": self.config.project_id, "Region": self.config.region}
         req and d.update(req)
-        d = apis.ModifyUHostInstanceTagRequestSchema().dumps(d)
+        d = apis.DescribeUHostTagsRequestSchema().dumps(d)
 
-        resp = self.invoke("ModifyUHostInstanceTag", d, **kwargs)
-        return apis.ModifyUHostInstanceTagResponseSchema().loads(resp)
+        resp = self.invoke("DescribeUHostTags", d, **kwargs)
+        return apis.DescribeUHostTagsResponseSchema().loads(resp)
+
+    def poweroff_uhost_instance(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ PoweroffUHostInstance - 直接关闭UHost实例电源，无需等待实例正常关闭。
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param UHostId: (Required) UHost实例ID 参见 [DescribeUHostInstance](./describe_uhost_instance.html)
+        :param Zone: (Optional) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.PoweroffUHostInstanceRequestSchema().dumps(d)
+
+        resp = self.invoke("PoweroffUHostInstance", d, **kwargs)
+        return apis.PoweroffUHostInstanceResponseSchema().loads(resp)
+
+    def terminate_custom_image(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ TerminateCustomImage - 删除用户自定义镜像
+
+        :param ProjectId: (Config) 项目ID。不填写为默认项目，子帐号必须填写。 请参考[GetProjectList接口](../summary/get_project_list.html)
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param ImageId: (Required) 自制镜像ID 参见 [DescribeImage](describe_image.html)
+        """
+        # build request
+        d = {"ProjectId": self.config.project_id, "Region": self.config.region}
+        req and d.update(req)
+        d = apis.TerminateCustomImageRequestSchema().dumps(d)
+
+        resp = self.invoke("TerminateCustomImage", d, **kwargs)
+        return apis.TerminateCustomImageResponseSchema().loads(resp)
+
+    def upgrade_to_ark_uhost_instance(
+        self, req: typing.Optional[dict] = None, **kwargs
+    ) -> dict:
+        """ UpgradeToArkUHostInstance - 普通升级为方舟机型
+
+        :param Region: (Config) 地域。 参见 [地域和可用区列表](../summary/regionlist.html)
+        :param UHostIds: (Required) UHost主机的资源ID，例如UHostIds.0代表希望升级的主机1，UHostIds.1代表主机2。
+        :param Zone: (Required) 可用区。参见 [可用区列表](../summary/regionlist.html)
+        :param CouponId: (Optional) 代金券ID 请参考DescribeCoupon接口
+        """
+        # build request
+        d = {"Region": self.config.region}
+        req and d.update(req)
+        d = apis.UpgradeToArkUHostInstanceRequestSchema().dumps(d)
+
+        resp = self.invoke("UpgradeToArkUHostInstance", d, **kwargs)
+        return apis.UpgradeToArkUHostInstanceResponseSchema().loads(resp)
